@@ -1,8 +1,9 @@
-# $Id: Calc.pm,v 1.20 2006/12/10 21:29:45 cfaerber Exp $
+# $Id: Calc.pm,v 1.21 2008/09/14 12:30:22 cfaerber Exp $
 #
 package Color::Calc;
 
 use strict;
+use warnings;
 
 use Carp;
 use Exporter;
@@ -12,7 +13,7 @@ use POSIX;
 use Graphics::ColorNames qw( hex2tuple tuple2hex );
 use Graphics::ColorNames::HTML;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 $VERSION = eval $VERSION;
 
 our $MODE = ();
@@ -305,10 +306,10 @@ Color::Calc - Simple calculations with RGB colors.
 
   use Color::Calc ();
   my $background = 'green';
-  print 'background: ',Color::Calc::color_html($background),';';
-  print 'border-top: solid 1px ',Color::Calc::light_html($background),';';
-  print 'border-bottom: solid 1px ',Color::Calc::dark_html($background),';';
-  print 'color: ',contrast_bw_html($background),';';
+  print 'background: ',Color::Calc::color_html($background),";\n";
+  print 'border-top: solid 1px ',Color::Calc::light_html($background),";\n";
+  print 'border-bottom: solid 1px ',Color::Calc::dark_html($background),";\n";
+  print 'color: ',Color::Calc::contrast_bw_html($background),";\n";
 
 =head1 DESCRIPTION
 
@@ -362,6 +363,14 @@ Default: C<__MODEvar>
 
 =back
 
+=item set_output_format
+
+  $cc->set_output_format( $format );
+
+Changes the output format for an existing C<Color::Calc> object.  
+
+=back
+
 =head3 Importing customised functions
 
 You can also choose to import customised funtions into your
@@ -444,7 +453,7 @@ the various packages with and without the C<color> prefix:
 
   print Color::Calc::WWW::color('FFF');		# prints 'white'
   print Color::Calc::WWW::color_invert('FFF');	# prints 'black'
-  print Color::Calc::html::invert('FFF');	# prints 'black'
+  print Color::Calc::WWW::invert('FFF');	# prints 'black'
 
 For the main module C<Color::Calc>, you can also add a suffix
 C<_I<output_format>> to select the output format:
@@ -453,7 +462,7 @@ C<_I<output_format>> to select the output format:
 
   print Color::Calc::color_html('FFF');		# prints 'white'
   print Color::Calc::color_invert_html('FFF');	# prints 'black'
-  print Color::Calc::invert_hex('FFF');		# prints '000000'
+  print Color::Calc::color_invert_hex('FFF');	# prints '000000'
 
 =head2 Color formats
 
@@ -558,6 +567,8 @@ this variable.
 The module supports the following calculation functions, which can
 be accessed through one of the methods described above:
 
+=over
+
 =item get($color)
 
 Returns C<$color> as-is (but in the selected output format). This
@@ -583,7 +594,7 @@ The optional C<$alpha> parameter can be a value between 0.0 (use
 C<$color1> only) and 1.0 (use C<$color2> only), the default is
 0.5.
 
-=item color_light($color [, $alpha])
+=item light($color [, $alpha])
 
 Returns a lighter version of C<$color>, i.e. returns
 C<mix($color,[255,255,255],$alpha)>.
@@ -652,13 +663,9 @@ L<Graphics::ColorNames> (required);
 
 L<Graphics::ColorObject> (optional)
 
-=head1 AUTHOR
+=head1 AUTHOR/LICENSE
 
-Claus Frber <cfaerber@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright  2004-2006 Claus Frber
+Copyright  2004-2008 Claus Frber <CFAERBER@cpan.org>
 
 This module is free software; you can redistribute it and/or
 modify it under the terms of either the GNU General Public License
